#!/bin/bash

SCRIPTPATH="$( cd "$(dirname "$0")" >/dev/null 2>&1 ; pwd -P )"

BUILD_CONFIG=build.config
PROJECT_PATH=""
BOARD_TYPE=""
OPENOCD="/usr/local/bin/openocd"
OPENOCD_PATH="/usr/local/share/openocd/scripts"
OPENOCD_ADAPTER=cmsis-dap
DOCKER_IMAGE="labinfo.ing.he-arc.ch:5050/igib/public/raspberry-pi-pico/raspberry-pi-pico-sdk"

help()
{
    echo "Build Raspberry Pi Pico projects"
    echo
    echo "Syntax: $0 [-b|c|d|f|h|p] <args>"
    echo "[ -b ]        Build project."
    echo "[ -c ]        Clean"
    echo "[ -d ]        Launch debugger"
    echo "[ -f ]        Flash board"
    echo "[ -h ]        Help"
    echo "[ -p PATH ]   Set project path"
    # echo "[ -t BOARD ]  Set board type"
}

init_config()
{
if [ ! -f $BUILD_CONFIG ]; then
    touch $BUILD_CONFIG
    echo "PROJECT_PATH=\"\"" >> $BUILD_CONFIG
    echo "BOARD_TYPE=\"\"" >> $BUILD_CONFIG
fi
}

check_docker_image_present()
{
    echo "Searching docker image"
    image="$(docker images | grep $DOCKER_IMAGE)"
    if [ -z "${image}" ]; then
        echo "Pulling image from remote"
        docker pull $DOCKER_IMAGE
    fi

    echo "Image found"
}

build=0
clean=0
debug=0
flash=0

if [ $# -eq 0 ]; then
    echo "Error: missing arguments"
    help
    exit 0
else
    while getopts "bcdfhp:t:" opt; do
        case $opt in
            b)
                build=1
                ;;
            c)
                clean=1
                ;;
            d)
                debug=1
                ;;
            
            f)
                flash=1
                ;;
            h)
                help
                exit 1
                ;;
            p)
                PROJECT_PATH=${OPTARG}

                if [ ! -d $PROJECT_PATH ]; then
                    echo "${PROJECT_PATH} does not exist"
                    exit 1
                fi

                # init_config

                # sed -i "1s#.*#PROJECT_PATH=$PROJECT_PATH#" $BUILD_CONFIG
                ;;

            t)
                # BOARD_TYPE=${OPTARG}

                # init_config

                # sed -i "2s/.*/BOARD_TYPE=$BOARD_TYPE/" $BUILD_CONFIG
                ;;

            \?)
                help
                exit 1
                ;;
            :)
                echo "Option -$OPTARG requires an argument." >&2
                exit 1
                ;;
        esac
    done
fi

# Check if config file exists
# if [ ! -f $BUILD_CONFIG ]; then
#     echo "Error no config file found. Please run $0 -p <project_path> -t <board_type>"
#     exit 1
# else
#     # Read config file
#     source $BUILD_CONFIG
    
#     if [ "${PROJECT_PATH}" == "" ]; then
#         echo "Error: Project path not found"
#         exit 1
#     fi

#     if [ "${BOARD_TYPE}" == "" ]; then
#         echo "Error: Board type not found"
#         exit 1
#     fi
# fi

if [ -z "${PROJECT_PATH}" ]; then
    echo "Error: Missing project path"
    exit 1
fi

if [ $clean == 1 ]; then
    cd ${PROJECT_PATH}build
    make clean
fi

if [ $build == 1 ]; then
    echo "Building project ${PROJECT_PATH}"
    
    check_docker_image_present

    docker run --rm -v $SCRIPTPATH:/mnt -w /mnt/${PROJECT_PATH} $DOCKER_IMAGE -c '
        source .config && cd $SRC_PATH && \
        mkdir -p build && cd build && \
        cmake cmake -DPICO_BOARD=$BOARD_TYPE .. && \
        make
    '
fi

if [ $flash == 1 ]; then
    # Find program
    PROGRAM="$(find ${PROJECT_PATH}/build -maxdepth 1 -type f -name "*.elf")"
    echo "Flashing ${PROGRAM}"
    sudo openocd -f interface/${OPENOCD_ADAPTER}.cfg -f target/rp2040.cfg -c "adapter speed 5000" -c "program ${PROGRAM} verify reset exit"
fi

if [ $debug == 1 ]; then
    sudo openocd -f interface/${OPENOCD_ADAPTER}.cfg -f target/rp2040.cfg -c "adapter speed 5000"
fi