#include <string.h>
#include <stdio.h>
#include <stdlib.h>
#include "pico/stdlib.h"
#include "hardware/pwm.h"
#include "hardware/uart.h"

#define PWM_PIN         5 // GP5 or pin 7
#define PWM_PERIOD      1000
#define CLOCK_FREQ      125000000 // 125 MHz
#define PWM_FREQ        100000 // 100 kHz
#define WRAP            CLOCK_FREQ / PWM_FREQ

static uint slice_num = 0;
static uint channel = 0;

/**
 * @brief Set the pwm duty cycle object
 * 
 * @param duty_cycle Duty cycle in % [0-100]
 */
void set_pwm_duty_cycle(uint8_t duty_cycle)
{
    if (duty_cycle > 100)
        return;

    double level = (double)WRAP / 100.0 * duty_cycle;
    pwm_set_chan_level(slice_num, channel, (uint16_t)level);
}

void on_uart_rx()
{
    char c;
    char *buf = new char[256];
    char *begin = buf;
    bool end = false;

    if(uart_is_readable(uart0)) {

        do {
            c = uart_getc(uart0);
            printf("%c", c);

            switch (c)
            {
            case '\n':
                end = true;
                break;
            
            case '\r':
                end = true;
                break;
            default:
                
                *buf = c;
                buf++;
                break;
            }
        } while(!end);

        buf++;
        *buf = '\0';
        buf = begin;
        
        uint8_t duty = strtoul(buf, NULL, 0);
        set_pwm_duty_cycle(duty);
        printf("\n");
    }
}

int main()
{
    stdio_init_all();
    printf("Hello from pwm\n");

    gpio_set_function(PWM_PIN, GPIO_FUNC_PWM);

    slice_num = pwm_gpio_to_slice_num(PWM_PIN);
    channel = pwm_gpio_to_channel(PWM_PIN);

    pwm_set_wrap(slice_num, WRAP);
    set_pwm_duty_cycle(50);
    pwm_set_enabled(slice_num, true);

    uart_set_fifo_enabled(uart0, true);
    irq_set_exclusive_handler(UART0_IRQ, on_uart_rx);
    irq_set_enabled(UART0_IRQ, true);

    uart_set_irq_enables(uart0, true, false);

    while(1)
        tight_loop_contents();

    return 0;
}