# SHT30 sensor example

This project contains an application that uses the SHT30 Temperature and Humidity sensor and broadcast their values over UDP.

## Application

The Raspberry Pi Pico expect to connect to an WiFi network with the following characteristics:

|      |           |
|------|-----------|
| SSID | IGIB_WiFi |
| Password | 1234567890 | 

Once connected to the network it will start a loop that send UDP packages at regular intervals.

|   |   |
|---|---|
| Pico IP | 192.168.1.102 |
| UDP port | 4444 |

A led flashes every 0.5s to indicate that everything is running correctly. If an error occurred the led will flash with a pattern.
This pattern is a number of flashes every 0.25s and a pause of 2s. The table below shows the meaning of each pattern.

| No. of flashes | Error description |
|----------------|-------------------|
| 1 | Failed to connect to WiFi network |
| 2 | Failed to connect the SHT30 sensor |
| 3 | Failed to setup timer |
| 4 | Failed to take a measure |

## Build script setup

| Configuration | Command |
|---------------|---------|
| Project path | ./build.sh -p sht30/pico_w | 
| Board type | ./build.sh -t grove_pico_w | 

## Hardware connection

The application expect to find the SHT30 on the *I2C0* channel.
Some messages are printed on the *UART0* port and can be used for debug (Baud 115200).
You can mount the Pico on a [Grove Basic Kit for Raspberry Pi Pico][1] and connect the SHT30 as well as the UART to the shield.

![Grove shield image](img/grove_shield_sht30.drawio.png)

## UDP client 

The *python* folder contains a simple UDP client that store received values in CSV file. To use it connect to
the same wifi network then run the client.

```bash
./udp_client.py
```

## Grove shield schematic

![Grove shield sch](img/Grove_shield_SCH.png)

[1]:https://wiki.seeedstudio.com/Grove-Starter-Kit-for-Raspberry-Pi-Pico/#schematic-online-viewer