#pragma once

#include "grove_pico_w.h"
#include "hardware/i2c.h"

class SHT30
{
    private:
        unsigned int i2c_channel_;
        i2c_inst *i2c_inst_;
        unsigned int i2c_sda_;
        unsigned int i2c_scl_;
        bool connected_;

        bool write_command(uint8_t *cmd, size_t len);
        bool write_command(uint16_t cmd);
        bool read_response(uint16_t *buf, size_t len);
        bool reset();

    public:

        struct measure {
            float temperature;
            float humidity;
            uint16_t raw_temperature;
            uint16_t raw_humidity;
        };

        enum Repeatability {
            LOW = 0,
            MEDIUM,
            HIGH
        };

        SHT30(unsigned int i2c_channel = PICO_I2C0);
        ~SHT30();
        bool is_connected();
        bool read_status_reg(uint16_t &reg);
        bool read_serial_number();
        bool heater_enable();
        bool heater_disable();
        bool single_measure(Repeatability repeatability, struct measure &measure, bool clock_stretching = true);
};